##  Best Practices for Getting Started
While building your inventory, what constitutes an application should be easily understood by everyone in the organization. Applications could be:
  * Commercial off-the-shelf (COTS) applications like Oracle Financials or Anaplan
  * Open-source applications like Jenkins or Drupal
  * Custom-built applications developed by your organization, whether deployed in the cloud or on-premise.
  * Even simple tools, like a spreadsheet (XLS file) or a SharePoint site that supports business processes, can be considered applications.


We strongly recommend starting with logical applications in the initial stage, focusing on quick wins around [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases."). As your EA practice advances, you can expand your modeling to include other fact sheet subtypes.
Make use of the reference catalog and SaaS discovery features to model SaaS services. This helps you easily build an inventory of associated IT components and providers, which will be relevant for realizing scenarios and generating reports down the road. To learn more, see [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.") and [SaaS Discovery](https://help.sap.com/docs/leanix/ea/saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SaaS discovery identifies your organization's SaaS applications by integrating with SSO, SASE, and CASB solutions. It then updates and enriches fact sheets using the reference catalog.").
